@@ -415,10 +415,8 @@ def create_pfile(output_filename, feature_count, data):
     :param data: list of (x, y) tuples, where x is the feature vector
                  of dimension ``feature_count`` and y is a label.
     """
-    #f = tempfile.NamedTemporaryFile()
-    #input_filename = f.name
-    input_filename = "tmp.pfile"
-    f = open(input_filename, "w")
+    f = tempfile.NamedTemporaryFile(delete=False)
+    input_filename = f.name
 
     logging.debug(data)
     for symbolnr, instance in enumerate(data):
@@ -429,7 +427,7 @@ def create_pfile(output_filename, feature_count, data):
         feature_string = " ".join(map(str, feature_string))
         line = "%i 0 %s %i" % (symbolnr, feature_string, label)
         print(line, file=f)
-        logging.debug(line)
+    f.close()
 
     command = "pfile_create -i %s -f %i -l 1 -o %s" % \
               (input_filename, feature_count, output_filename)
@@ -438,7 +436,7 @@ def create_pfile(output_filename, feature_count, data):
     if return_code != 0:
         logging.error("pfile_create failed with return code %i." % return_code)
         sys.exit(-1)
-    f.close()
+    os.remove(input_filename)
 
 
 def get_recognizer_folders(model_folder):
@@ -486,8 +484,9 @@ def evaluate_model(recording, model_folder, verbose=False):
             x = handwriting.feature_extraction(feature_list)
 
             # Create pfile
-            output_file_pointer = tempfile.NamedTemporaryFile()
+            output_file_pointer = tempfile.NamedTemporaryFile(delete=False)
             output_filename = output_file_pointer.name
+            output_file_pointer.close()
             create_pfile(output_filename, feature_count, [(x, 0)])
         elif "model" in target_folder:
             logging.info("Create running model...")
@@ -519,7 +518,7 @@ def evaluate_model(recording, model_folder, verbose=False):
             return logfile
         else:
             logging.info("'%s' not found", target_folder)
-    output_file_pointer.close()
+    os.remove(output_filename)
 
 
 def classify_single_recording(raw_data_json, model_folder, verbose=False):
